@@ -40,7 +40,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MINOR_VERSION (8)
+#define GTK_SOURCE_MINOR_VERSION (14)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -49,7 +49,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MICRO_VERSION (0)
+#define GTK_SOURCE_MICRO_VERSION (1)
 
 
 /**
@@ -127,6 +127,26 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_5_8 (G_ENCODE_VERSION (5, 8))
 
+/**
+ * GTK_SOURCE_VERSION_5_10:
+ *
+ * A macro that evaluates to the 5.10 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.10
+ */
+#define GTK_SOURCE_VERSION_5_10 (G_ENCODE_VERSION (5, 10))
+
+/**
+ * GTK_SOURCE_VERSION_5_12:
+ *
+ * A macro that evaluates to the 5.12 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.12
+ */
+#define GTK_SOURCE_VERSION_5_12 (G_ENCODE_VERSION (5, 12))
+
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
 #ifndef __GTK_DOC_IGNORE__
 #  if (GTK_SOURCE_MINOR_VERSION % 2)
@@ -198,42 +218,48 @@ G_BEGIN_DECLS
 #error "GTK_SOURCE_VERSION_MIN_REQUIRED must be >= GTK_SOURCE_VERSION_5_0"
 #endif
 
-#ifndef __GTK_DOC_IGNORE__
-#define GTK_SOURCE_AVAILABLE_IN_ALL _GTK_SOURCE_EXTERN
-#endif
-
 /* Every new stable minor release should add a set of macros here */
 
 #ifndef __GTK_DOC_IGNORE__
+
+#define GTK_SOURCE_AVAILABLE_IN_ALL _GTK_SOURCE_EXTERN
+
 #if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_2
-#define GTK_SOURCE_AVAILABLE_IN_5_2 G_UNAVAILABLE(5, 2) _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_2 G_UNAVAILABLE(5, 2) _GTK_SOURCE_EXTERN
 #else
-#define GTK_SOURCE_AVAILABLE_IN_5_2 _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_2 _GTK_SOURCE_EXTERN
 #endif
-#endif /* __GTK_DOC_IGNORE__ */
 
-#ifndef __GTK_DOC_IGNORE__
 #if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_4
-#define GTK_SOURCE_AVAILABLE_IN_5_4 G_UNAVAILABLE(5, 4) _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_4 G_UNAVAILABLE(5, 4) _GTK_SOURCE_EXTERN
 #else
-#define GTK_SOURCE_AVAILABLE_IN_5_4 _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_4 _GTK_SOURCE_EXTERN
 #endif
-#endif /* __GTK_DOC_IGNORE__ */
 
-#ifndef __GTK_DOC_IGNORE__
 #if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_6
-#define GTK_SOURCE_AVAILABLE_IN_5_6 G_UNAVAILABLE(5, 6) _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_6 G_UNAVAILABLE(5, 6) _GTK_SOURCE_EXTERN
 #else
-#define GTK_SOURCE_AVAILABLE_IN_5_6 _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_6 _GTK_SOURCE_EXTERN
 #endif
-#endif /* __GTK_DOC_IGNORE__ */
 
-#ifndef __GTK_DOC_IGNORE__
 #if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_8
-#define GTK_SOURCE_AVAILABLE_IN_5_8 G_UNAVAILABLE(5, 8) _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_8 G_UNAVAILABLE(5, 8) _GTK_SOURCE_EXTERN
 #else
-#define GTK_SOURCE_AVAILABLE_IN_5_8 _GTK_SOURCE_EXTERN
+# define GTK_SOURCE_AVAILABLE_IN_5_8 _GTK_SOURCE_EXTERN
 #endif
+
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_10
+# define GTK_SOURCE_AVAILABLE_IN_5_10 G_UNAVAILABLE(5, 10) _GTK_SOURCE_EXTERN
+#else
+# define GTK_SOURCE_AVAILABLE_IN_5_10 _GTK_SOURCE_EXTERN
+#endif
+
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_12
+# define GTK_SOURCE_AVAILABLE_IN_5_12 G_UNAVAILABLE(5, 12) _GTK_SOURCE_EXTERN
+#else
+# define GTK_SOURCE_AVAILABLE_IN_5_12 _GTK_SOURCE_EXTERN
+#endif
+
 #endif /* __GTK_DOC_IGNORE__ */
 
 GTK_SOURCE_AVAILABLE_IN_ALL
